﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace TECHIS.Cloud.Configuration.Test
{
    [TestClass]
    public class AppConfigurationProviderTests
    {

        [TestMethod]
        public void ReadDefaultAccess()
        {
            TestRetrieve();
        }

        [TestMethod]
        public void ReadWithNoAzureStorageConnectionString()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = "ApplicationName=sales.analytics;EnvironmentName=e.dev",
                AzureStorageConnectionString = null
            };

            try
            {
                TestRetrieve(connSettings);
            }
            catch (Exception xc)
            {
                Assert.IsTrue( Errors.IsSource(xc, Errors.STORE_CONNECTION_INVALID));
            }
        }
        [TestMethod]
        public void ReadWithNameOnly()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = "sales.analytics",
                AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };

            TestRetrieve(connSettings);
        }
        [TestMethod]
        public void ReadWithDisabledACServerConnectionString()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = "ApplicationName=sales.analytics;Disabled=true",
                AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };

            TestRetrieve(connSettings);
        }
        

        [TestMethod]
        public void ReadWithNoAppConfigServerConnectionString()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = null,
                AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };
            try
            {
                TestRetrieve(connSettings);
            }
            catch (Exception xc)
            {
                Assert.IsTrue(Errors.IsSource(xc, Errors.APPLICATIONNAME_REQUIRED));
            }
        }


        private static Types.SampleConfiguration TestRetrieve(ConnectionSettings conSettings = null)
        {
            var provider = new AppConfigurationProvider(conSettings);

            var result = provider.Get<Types.SampleConfiguration>();

            Assert.AreNotEqual(null, result, "AppConfigurationProvider.Get should return deserialized object");
            Assert.AreNotEqual(null, result.Name, "The Name property of deserialized object shouldn't be null");
            Assert.AreNotEqual(0, result.Name.Length, "The Name property of deserialized object shouldn't be an empty string");

            return result;
        }
    }
}
