﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace TECHIS.Cloud.Configuration.Test
{
    [TestClass]
    public class AzureBlobStorageReaderTests
    {
        [TestMethod]
        public void ReadDefaultAccess()
        {
            TestRead();
        }

        [TestMethod]
        public void ReadWithEnvironName()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = "ApplicationName=sales.analytics;EnvironmentName=e.dev",
                AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };

            TestRead(connSettings);
        }
        [TestMethod]
        public void ReadWithNameOnly()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = "sales.analytics",
                AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };

            TestRead(connSettings);
        }
        [TestMethod]
        public void ReadWithFileName()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = "ApplicationName=sales.analytics;FileName=config.json",
                AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };

            TestRead(connSettings);
        }

        [TestMethod]
        public void ReadJson()
        {
            var connSettings = new ConnectionSettings
            {
                AppConfigConnectionString = "ApplicationName=sales.analytics;FileName=config.json",
                AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };

            string result=TestRead(connSettings);

            result = result.Trim();
            Assert.IsTrue( result[0] == '{', "Return data is not Json");
            Assert.IsTrue(result[result.Length-1] == '}', "Return data is not Json");
        }

        [TestMethod]
        public void ReadWithNoAC_ConnectionString()
        {
        var connSettings = new ConnectionSettings
        {
            AppConfigConnectionString = null,
            AzureStorageConnectionString = GlobalConstants.CONNECTIONSTING_AZURE_STORAGE
            };
            try
            {
                TestRead(connSettings);
            }
            catch (Exception xc)
            {
                Assert.IsTrue(Errors.IsSource(xc, Errors.APPLICATIONNAME_REQUIRED));
            }
        }


        private static string TestRead(ConnectionSettings conSettings = null)
        {
            var bsReader = new AzureBlobStorageReader(conSettings);

            var result = bsReader.ReadText();

            Assert.AreNotEqual(null, result,        "ReadText should return text from Azure Storage");
            Assert.AreNotEqual(0, result.Length,    "ReadText should return text from Azure Storage");

            return result;
        }
    }
}
